# ----- Define a function for plotting a matrix ----- #
myImagePlot <- function(x, all_yLabels=F, ...){
     min <- min(x)
     max <- max(x)
     yLabels <- as.numeric(rownames(x))
     xLabels <- as.numeric(colnames(x))
     title <-c()
  # check for additional function arguments
  if( length(list(...)) ){
    Lst <- list(...)
    if( !is.null(Lst$zlim) ){
       min <- Lst$zlim[1]
       max <- Lst$zlim[2]
    }
    if( !is.null(Lst$yLabels) ){
       yLabels <- c(Lst$yLabels)
    }
    if( !is.null(Lst$xLabels) ){
       xLabels <- c(Lst$xLabels)
    }
    if( !is.null(Lst$title) ){
       title <- Lst$title
    }
  }
# check for null values
if( is.null(xLabels) ){
   xLabels <- c(1:ncol(x))
}
if( is.null(yLabels) ){
   yLabels <- c(1:nrow(x))
}

layout(matrix(data=c(1,2), nrow=1, ncol=2), widths=c(4,1), heights=c(1,1))

 # Red and green range from 0 to 1 while Blue ranges from 1 to 0
 ColorRamp <- rev(pal(1000)[c(seq(1,401,10),402:599,seq(600,1000,10))]) #rgb( seq(0,1,length=256),  # Red
                   #seq(0,1,length=256),  # Green
                   #seq(1,0,length=256))  # Blue
 ColorLevels <- seq(0, 1, length=length(ColorRamp))

 # Reverse Y axis
 reverse <- nrow(x) : 1
 yLabels <- yLabels[reverse]
 x <- x[reverse,]

 # Data Map
 par(mar = c(3,5,2.5,2))
 image(1:length(xLabels), 1:length(yLabels), t(x), col=ColorRamp, xlab="",
 ylab="", axes=FALSE, zlim=c(0,1))
 if( !is.null(title) ){
    title(main=title)
 }
 axis(BELOW<-1, at=0:(length(xLabels)+1), labels=F, tcl=-0.2)
 axis(BELOW<-1, at=seq(1,ny,5), labels=seq(1,ny,5)+xLabels[1]-1, cex.axis=1.2, tcl=-.5)
 axis(LEFT <-2, at=0:(ns+1), labels=F, las= HORIZONTAL<-1, cex.axis=1.2,tcl=-.2)
 axis(LEFT <-2, at=seq(1,ns,5), labels=yLabels[seq(1,ns,5)], las= HORIZONTAL<-1, cex.axis=1.2,tcl=-.5)
 if (all_yLabels){  axis(LEFT <-2, at=1:ns, labels=yLabels, las= HORIZONTAL<-1, cex.axis=1.2,tcl=-.5)  }

 # Color Scale
 par(mar = c(3,2.5,2.5,2))
 image(1, ColorLevels,
      matrix(data=ColorLevels, ncol=length(ColorLevels),nrow=1),
      col=ColorRamp,
      xlab="",ylab="",
      xaxt="n",cex.axis=1.2)

 layout(1)
}
# ----- END plot function ----- #
