# This script produces a figure on individual trends, like Fig6 of the paper

# Inputs
#	idt	: a NSx3 matrix providing the [best_estimate, lower_bound, upper_bound] for each single station
#	ll_tmp	: a NSx2 matrix providing the coordinates of each single station



# Figure
if (dev.cur()==1){x11(width=9,height=8)}
layout(matrix(c(1,2,3,4), 2, 2, byrow = TRUE))
# Panel 1 : Collection d'IC
if (max(dim(ll_tmp))>15) xlab_name="Stations" else xlab_name="Clusters"
print(xlab_name)
par(fig=c(0,1,.5,1),plt=c(.14,.95,.2,.95),mgp=c(2.2,.7,0),cex.lab=1.2,cex.axis=1.2,las=1,font=2)
ns = dim(idt)[2]
plot(1:ns,idt[1,],type="p",pch=9,xlim=c(0,1.15*ns),ylim=c(min(idt),.6),cex.lab=1.2,cex.axis=1.2,las=1,xlab=xlab_name,ylab="",main="",yaxt="n",font.lab=2,font=2)
loc = seq(-1,2,.1)
title(ylab="Relative change",mgp=c(4.5,.7,0),cex.lab=1.2,font.lab=2)
signe_loc = as.character(loc)
signe_loc[loc==0] = " "
signe_loc[loc>0] = "+"
signe_loc[loc<0] = "-"
loc_names = paste(signe_loc,"",as.character(abs(100*loc)),"%",sep="")
axis(2,at=loc,labels=loc_names,las=1,font=2,mgp=c(3,.7,0))
dd=.04
xpos = 1.1*ns
abline(h=cc_change,col="green",lty=2)
text(xpos,cc_change+dd,"1xCC",col="green")
abline(h=ic14[2],col="red",lty=2)
text(xpos,ic14[2]+.6*dd,"Reg. Avg.",col="red")
abline(h=2*cc_change,col="green",lty=2)
text(xpos,2*cc_change+dd,"2xCC",col="green")
abline(h=3*cc_change,col="green",lty=2)
text(xpos,3*cc_change+dd,"3xCC",col="green")
abline(h=0,col="black",lty=2)
for (i in 1:ns){
  lines(c(i,i),idt[2:3,i])
}
curr_xlim = par("usr")
mtext("a)",side=3,lwd=2,at=-(curr_xlim[2]-curr_xlim[1])/6,line=0,cex=1.2)
# Panel 2 : Histogramme
par(fig=c(0,.4,0,.5),plt=c(.25,.95,.35,.85),mgp=c(2.8,.7,0),cex.lab=1.2,cex.axis=1.2,las=1,new=T,font=2,yaxs="i")
aa = hist(100*idt[1,],plot=F)
fmax = 5* ceiling(max(aa$counts)/5)
hist(100*idt[1,],main="",freq=T,xlab="",ylab="Number of Stations",font.lab=2,font=2,xaxt="n",yaxt="n",ylim=c(0,fmax))
axis(1,at=100*loc,labels = loc_names,las=3,font=2,mgp=c(3,.7,0))
axis(2,at=seq(0,20,5),labels=as.character(seq(0,20,5)),las=1,font=2,mgp=c(3,.7,0))
title(xlab="Relative change",mgp=c(5,.7,0),font.lab=2)
curr_xlim = par("usr")
mtext("b)",side=3,lwd=2,at=curr_xlim[1]-(curr_xlim[2]-curr_xlim[1])/5,line=2.5,cex=1.2)
# Panel 3 : Carte
par(fig=c(.4,.85,0,.5),mar=c(3,3,1,1),new=T)
plot(ll_tmp$lon,ll_tmp$lat,type="p",xlim=c(0,1),ylim=c(0,1),xlab="",ylab="",font.lab=2)
ym = 1.001*max(abs(idt[1,]))
col_num = ceiling( 100* (idt[1,]-(-ym)) / (2*ym) )
if (max(dim(ll_tmp))<15) par(lwd=10)
points(ll_tmp$lon,ll_tmp$lat,col=pal.qual(100)[col_num],pch=19)
#mtext("%",side=1,at=9,font=2,line=1)
mtext("c)",side=3,lwd=2,at=1.1,line=0,cex=1.2)
par(fig=c(.85,1,0,.5),mar=c(0,0,0,0),new=T,lwd=1)
image.plot(legend.only=TRUE,col=pal(100)[21:100], zlim= 100*c(-.6*ym,ym),smallplot=c(.05,.3,.15,.9),axis.args=list(at=100*loc,labels=loc_names))
axis(2,at=seq(0,20,5),labels=as.character(seq(0,20,5)),las=1,font=2,mgp=c(3,.7,0))

